@@ -119,7 +119,7 @@ public class CDFConvert extends JFrame
     JRadioButton encoding0 = new JRadioButton("Source");
     JRadioButton encoding1 = new JRadioButton("Host");
     JRadioButton encoding2 = new JRadioButton("Network");
-    JRadioButton encoding3 = new JRadioButton("Macintosh");
+    JRadioButton encoding3 = new JRadioButton("PPC");
     JRadioButton encoding4 = new JRadioButton("DECstation");
     JRadioButton encoding5 = new JRadioButton("Sun");
     JRadioButton encoding6 = new JRadioButton("VAX");
@@ -308,8 +308,8 @@ public class CDFConvert extends JFrame
     }
 
     CDFConvert(JFrame parentDriver, String cdfbase, boolean modal) {
-        if (cdfbase != null) command = cdfbase + separator + "bin" + 
-				       separator + "cdfconvert ";
+        if (cdfbase != null) command = "\"" + cdfbase + separator + "bin" + 
+				       separator + "cdfconvert\" ";
         dialog = new JDialog(this, modal);
         this.modal = modal;
 	this.parentDriver = parentDriver;
@@ -376,11 +376,11 @@ public class CDFConvert extends JFrame
         makeJButton(panel1, cdf2, 1, 2, 1, 1, 1.0, 1.0);
 	makeJButton(panel1, Box.createRigidArea(hpad10), 2, 2, 1, 1, 1.0, 1.0);
         makeJButton(panel1, slt2, 3, 2, 1, 1, 1.0, 1.0);
-        makeJButton(panel1, SKLT, 0, 3, 1, 1, 1.0, 1.0);
-        makeJButton(panel1, sklt, 1, 3, 1, 1, 1.0, 1.0);
-	makeJButton(panel1, Box.createRigidArea(hpad10), 2, 3, 1, 1, 1.0, 1.0);
-        makeJButton(panel1, slt3, 3, 3, 1, 1, 1.0, 1.0);
-	makeJButton(panel1, Box.createRigidArea(vpad20), 0, 4, 1, 1, 1.0, 1.0);
+//        makeJButton(panel1, SKLT, 0, 3, 1, 1, 1.0, 1.0);
+//        makeJButton(panel1, sklt, 1, 3, 1, 1, 1.0, 1.0);
+//	makeJButton(panel1, Box.createRigidArea(hpad10), 2, 3, 1, 1, 1.0, 1.0);
+//        makeJButton(panel1, slt3, 3, 3, 1, 1, 1.0, 1.0);
+	makeJButton(panel1, Box.createRigidArea(vpad20), 0, 3, 1, 1, 1.0, 1.0);
 
         cdf1.addActionListener(this);
         cdf1.addFocusListener(this);
@@ -506,7 +506,7 @@ public class CDFConvert extends JFrame
         encoding0.setActionCommand("source");
         encoding1.setActionCommand("host");
         encoding2.setActionCommand("network");
-        encoding3.setActionCommand("mac");
+        encoding3.setActionCommand("ppc");
         encoding4.setActionCommand("decstation");
         encoding5.setActionCommand("sun");
         encoding6.setActionCommand("vax");
@@ -555,7 +555,7 @@ public class CDFConvert extends JFrame
         encoding0.setToolTipText("Use the encoding from the source CDF for the destination CDF");
         encoding1.setToolTipText("Use the host machine encoding for the destination CDF");
         encoding2.setToolTipText("Use the network encoding for the destination CDF");
-        encoding3.setToolTipText("Use the Mac encoding for the destination CDF");
+        encoding3.setToolTipText("Use the PPC encoding for the destination CDF");
         encoding4.setToolTipText("Use the DECStation encoding for the destination CDF");
         encoding5.setToolTipText("Use the Sun encoding for the destination CDF");
         encoding6.setToolTipText("Use the VAX encoding for the destination CDF");
@@ -628,14 +628,17 @@ public class CDFConvert extends JFrame
 
 	panel2c.add(encodingPanel, BorderLayout.CENTER);
 
-        makeJButton(panel2s, Box.createRigidArea(vpad20), 0, 0, 1, 1, 1.0, 1.0);
-        makeJButton(panel2s, CASS, 0, 1, 1, 1, 1.0, 1.0);
-        makeJButton(panel2s, cachesizes, 1, 1, 2, 1, 1.0, 1.0);
-        makeJButton(panel2s, SPAR, 0, 2, 1, 1, 1.0, 1.0);
-        makeJButton(panel2s, sparseness, 1, 2, 2, 1, 1.0, 1.0);
-        makeJButton(panel2s, COMP, 0, 3, 1, 1, 1.0, 1.0);
-        makeJButton(panel2s, compression, 1, 3, 2, 1, 1.0, 1.0);
-	makeJButton(panel2s, Box.createRigidArea(vpad20), 0, 4, 1, 1, 1.0, 1.0);
+        makeJButton(panel2s, SKLT, 0, 1, 1, 1, 1.0, 1.0);
+        makeJButton(panel2s, sklt, 1, 1, 1, 1, 1.0, 1.0);
+//        makeJButton(panel2s, Box.createRigidArea(hpad10), 2, 1, 1, 1, 1.0, 1.0);
+        makeJButton(panel2s, slt3, 2, 1, 1, 1, 1.0, 1.0);
+        makeJButton(panel2s, CASS, 0, 2, 1, 1, 1.0, 1.0);
+        makeJButton(panel2s, cachesizes, 1, 2, 2, 1, 1.0, 1.0);
+        makeJButton(panel2s, SPAR, 0, 3, 1, 1, 1.0, 1.0);
+        makeJButton(panel2s, sparseness, 1, 3, 2, 1, 1.0, 1.0);
+        makeJButton(panel2s, COMP, 0, 4, 1, 1, 1.0, 1.0);
+        makeJButton(panel2s, compression, 1, 4, 2, 1, 1.0, 1.0);
+	makeJButton(panel2s, Box.createRigidArea(vpad20), 0, 5, 1, 1, 1.0, 1.0);
 
         panel2.add(panel2n, BorderLayout.NORTH);
         panel2.add(panel2c, BorderLayout.CENTER);
