@@ -1,4 +1,4 @@
-// $Id: CDFDialog.java,v 1.1.1.1 2009/01/20 16:27:23 liu Exp $
+// $Id: CDFDialog.java,v 1.1.1.1 2010/01/13 20:06:14 liu Exp $
 
 import javax.swing.*;
 import javax.swing.border.*;
@@ -91,7 +91,7 @@ public class CDFDialog extends JDialog implements ActionListener,
         encodingV.addElement("IBMPC");
         encodingV.addElement("IBMRS");
         encodingV.addElement("HOST");
-        encodingV.addElement("MAC");
+        encodingV.addElement("PPC");
         encodingV.addElement("HP");
         encodingV.addElement("NeXT");
 	encodingV.addElement("ALPHAOSF1");
@@ -226,7 +226,7 @@ public class CDFDialog extends JDialog implements ActionListener,
       public void itemStateChanged(ItemEvent event) {
         Object source = event.getSource();        
         int ind = cben.getIndex() + 1;
-	if (ind > MAC_ENCODING) ind++; 
+	if (ind > PPC_ENCODING) ind++; 
 	if (ind != encoding) enChanged = true;
       }
     }
@@ -466,7 +466,7 @@ public class CDFDialog extends JDialog implements ActionListener,
 	    jtfcl.set("0");
         }
         ind = (int) encoding - 1;
-        if (ind > MAC_ENCODING) ind--;
+        if (ind > PPC_ENCODING) ind--;
         cben.setIndex(ind);
 
         ind = (int) majority - 1;
