@@ -138,10 +138,18 @@ public class CDFDir extends JFrame
 
     CDFDir(JFrame parentDriver, String cdfbase, boolean modal) {
         if (cdfbase != null) {
-	   command = cdfbase + separator + "bin" + 
-		     separator + "cdfdir ";
-	   helpolh = CDFToolsUtil.getenv("CDF_HELP") + separator +
-                     "cdfdirj.olh";
+	   command = "\"" + cdfbase + separator + "bin" + 
+		     separator + "cdfdir\" ";
+           String help = CDFToolsUtil.getenv("CDF_HELP");
+           if (help != null && help.length() > 0) {
+             String osName = System.getProperty("os.name");
+             if (osName.toLowerCase().indexOf("windows") != -1) {
+               int sepindx = help.indexOf(";");
+               if (sepindx != -1) 
+                 help = help.substring(0, sepindx);
+             } 
+             helpolh = help + separator + "cdfdirj.olh";
+           }
 	}
         dialog = new JDialog(this, modal);
 	this.parentDriver = parentDriver;
