@@ -61,6 +61,11 @@ public class CDFDump extends JFrame
 /** Text field for entering optional variable names. */
     JTextField vars = new JTextField("",40);
 
+/** A label of "Rec Ranges:" for the text field vars. */
+    JLabel RECS = new JLabel("Rec Ranges: ");
+/** Text field for entering optional variable names. */
+    JTextField recs = new JTextField("",40);
+
 /** "Enter" button. */
     JButton entrb = new JButton(" Enter ");
 /** "Help" button. */
@@ -110,7 +115,9 @@ public class CDFDump extends JFrame
     String xxx = " ";
     String cdfDelimiter = "";
     String strvars = "";
+    String strrecs = "";
     String yyy;
+    String zzz;
 
 /** A platform-dependent Runtime object. */
     Runtime runtime = Runtime.getRuntime();
@@ -186,8 +193,8 @@ public class CDFDump extends JFrame
     }
 
     CDFDump(JFrame parentDriver, String cdfbase, boolean modal) {
-        if (cdfbase != null) command = cdfbase + separator + "bin" + 
-				       separator + "cdfdump ";
+        if (cdfbase != null) command = "\"" + cdfbase + separator + "bin" + 
+				       separator + "cdfdump\" ";
         dialog = new JDialog(this, modal);
 	this.parentDriver = parentDriver;
         this.modal = modal;
@@ -309,7 +316,9 @@ public class CDFDump extends JFrame
         makeJButton(panel2s, Box.createRigidArea(vpad5), 0, 0, 1, 1, 0.0, 0.0);
         makeJButton(panel2s, VARS, 0, 1, 1, 1, 1.0, 1.0);
         makeJButton(panel2s, vars, 1, 1, 2, 1, 1.0, 1.0);
-        makeJButton(panel2s, Box.createRigidArea(vpad20), 0, 2, 1, 1, 1.0, 1.0);
+        makeJButton(panel2s, RECS, 0, 2, 1, 1, 1.0, 1.0);
+        makeJButton(panel2s, recs, 1, 2, 2, 1, 1.0, 1.0);
+        makeJButton(panel2s, Box.createRigidArea(vpad20), 0, 3, 1, 1, 1.0, 1.0);
         panel2.add(panel2n, BorderLayout.NORTH);
         panel2.add(panel2s, BorderLayout.SOUTH);
 
@@ -325,9 +334,15 @@ public class CDFDump extends JFrame
         vars.addMouseListener(this);
         vars.addFocusListener(this);
         vars.setToolTipText("Enter the selected variable names, separated by comma, in the CDF to be dumped");
+        recs.addActionListener(this);
+        recs.addMouseListener(this);
+        recs.addFocusListener(this);
+        recs.setToolTipText("Enter the comma-separated record range for all variables in the CDF to be dumped");
 
         VARS.setFont(boldFont);
         vars.setFont(boldFont);
+        RECS.setFont(boldFont);
+        recs.setFont(boldFont);
 
         dialog.getContentPane().add(panel2,BorderLayout.CENTER);
 
@@ -429,6 +444,7 @@ public class CDFDump extends JFrame
                 cdfspec = cdf.getText();
                 filespec = outf.getText();
                 strvars = vars.getText();
+                strrecs = recs.getText();
 
                 if (cdfspec.equals("") || cdfspec.trim().equals("")) {
                   info.setText("");
@@ -459,7 +475,12 @@ public class CDFDump extends JFrame
                 if (strvars.equals("") || strvars.trim().equals("")) 
                   yyy = " ";
                 else
-                  yyy = "-vars " + strvars.trim() + " ";
+                  yyy = "-vars '" + strvars.trim() + "' ";
+
+                if (strrecs.equals("") || strrecs.trim().equals(""))
+                  zzz = " ";
+                else
+                  zzz = "-recordrange '" + strrecs.trim() + "' ";
 
 		if (cdfspec.startsWith("'")) cdfDelimiter = " ";
 		else if (cdfspec.startsWith("\"")) cdfDelimiter = " ";
@@ -476,7 +497,7 @@ public class CDFDump extends JFrame
 		  strqe = " ";
 
 		commandX = command + struf + strqe + "-dump " + strdp + " " + 
-                           xxx + yyy + " " + cdfDelimiter + cdfspec + 
+                           xxx + yyy + " " + zzz + " " + cdfDelimiter + cdfspec + 
                            cdfDelimiter;
 
                 String OS = System.getProperty("os.name").toLowerCase();
