@@ -114,8 +114,8 @@ public class CDFInquire extends JFrame
     }
 
     CDFInquire(JFrame parentFrame, String cdfbase, boolean modal) {
-        if (cdfbase != null) command = cdfbase + separator + "bin" + 
-				       separator + "cdfinquire ";
+        if (cdfbase != null) command = "\"" + cdfbase + separator + "bin" + 
+				       separator + "cdfinquire\" ";
         dialog = new JDialog(this, modal);
 	this.parentFrame = parentFrame;
         this.modal = modal;
