@@ -96,7 +96,7 @@ public class CDFStats extends JFrame
 
 /** Text field for entering optional cache sizes. */
     JTextField cachesizes = new JTextField("",40);
-/** iext field for entering the mandatory source CDF file name. */
+/** Text field for entering the mandatory source CDF file name. */
     JTextField cdf = new JTextField("", 40);
 /** Text field for entering the optional destination output file name. */
     JTextField outf = new JTextField("", 40);
@@ -221,8 +221,8 @@ public class CDFStats extends JFrame
     }
 
     CDFStats(JFrame parentDriver, String cdfbase, boolean modal) {
-        if (cdfbase != null) command = cdfbase + separator + "bin" + 
-				       separator + "cdfstats ";
+        if (cdfbase != null) command = "\"" + cdfbase + separator + "bin" + 
+				       separator + "cdfstats\" ";
         dialog = new JDialog(this, modal);
 	this.parentDriver = parentDriver;
         this.modal = modal;
