@@ -24,7 +24,8 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
 /** The file separator. */
     String separator = System.getProperty("file.separator");
     String osName = System.getProperty("os.name");
-    JRadioButton rb1, rb2, rb3, rb4, rb5, rb6, rb7, rb8, rb9, rba, rbb, qut, non;
+    JRadioButton rb1, rb2, rb3, rb4, rb5, rb6, rb7, rb8, rb9, rba, rbb, rbc, qut, 
+                 non;
 /** The default file name at which the CDF logo file is located. */
 //    String basegif = cdfbase + separator + "java" + separator + "cdf_banner.jpg";
 /** The alternated file name for CDF logo if it is not at the default directory. */
@@ -55,6 +56,8 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
     String cdfdir = "CDFDir";
 /** The action command for selecting the CDFMerge radiobutton. */
     String cdfmerge = "CDFMerge";
+/** The action command for selecting the CDFValidate radiobutton. */
+    String cdfvalidate = "CDFValidate";
 /** The action command for selecting the CDFEdit radiobutton. */
     String cdfedit = "CDFEdit";
 /** The action command for selecting the CDFExport radiobutton. */
@@ -81,7 +84,7 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
 //  each tool program will run as an independent thread
     Thread threadinquire, threadstats, threadcompare, threadconvert,
            threadskeletontable, threadskeletoncdf, threaddump, threaddir,
-           threadmerge, threadedit, threadexport;
+           threadmerge, threadvalidate, threadedit, threadexport;
 
 //  Each tool as an object from its class 
 /** A CDFInquire object is initiated when it is selected to run.*/ 
@@ -98,6 +101,8 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
     CDFDir pgmdir = null;
 /** A CDFMerge object is initiated when it is selected to run.*/
     CDFMerge pgmmerge = null;
+/** A CDFValidate object is initiated when it is selected to run.*/
+    CDFValidate pgmvalidate = null;
 /** A SkeletonTable object is initiated when it is selected to run.*/
     SkeletonTable pgmskeletontable = null;
 /** A SkeletonCDF object is initiated when it is selected to run.*/
@@ -174,6 +179,12 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
                 System.err.println("Error with echo... 3 "+ee);
               }
               cdfbase = inStream.readLine();
+              if (cdfbase.toLowerCase().equals("%cdf_base%"))
+                cdfbase = null;
+              else {
+                int sepindx = cdfbase.indexOf(";");
+                if (sepindx != -1) cdfbase = cdfbase.substring(0, sepindx);
+              }
 	    } catch (IOException ex) { // No need to do anything if "cmd" file does not exist 
               cdfbase = null;
 	    } 
@@ -235,110 +246,115 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
 	panel1.setPreferredSize(new Dimension(200, 375));
 	panel1.setBorder(new TitledBorder(new EtchedBorder(), "Select a tool to run"));
 
-//	if (((osName.indexOf("Mac") == -1) || (osName.indexOf("Mac OS X") != -1)) && 
-//	    osName.indexOf("Windows") == -1) {
-        if ((osName.indexOf("Mac") == -1) || (osName.indexOf("Mac OS X") != -1)) {
+	rb1 = new JRadioButton("SkeletonTable");
+	rb1.setMnemonic('1');
+	rb1.setToolTipText("<html><center>"+
+			   "Run the command-line based SkeletonTable Tool Program."+
+			   "<br>"+
+			   "Need to define CDF_BASE environment variable."+
+			   "</center></html>");
+	rb1.setActionCommand(skeletontable);
+	rb1.addActionListener(this);
+	buttonGroup.add(rb1);
 
-	  rb1 = new JRadioButton("SkeletonTable");
-	  rb1.setMnemonic('1');
-	  rb1.setToolTipText("<html><center>"+
-			     "Run the command-line based SkeletonTable Tool Program."+
-			     "<br>"+
-			     "Need to define CDF_BASE environment variable."+
-			     "</center></html>");
-	  rb1.setActionCommand(skeletontable);
-	  rb1.addActionListener(this);
-	  buttonGroup.add(rb1);
+	rb2 = new JRadioButton("SkeletonCDF");
+	rb2.setMnemonic('2');
+	rb2.setToolTipText("<html><center>"+
+                           "Run the command-line based SkeletonCDF Tool Program."+
+                           "<br>"+
+                           "Need to define CDF_BASE environment variable."+
+                           "</center></html>");
+	rb2.setActionCommand(skeletoncdf);
+	rb2.addActionListener(this);
+	buttonGroup.add(rb2);
 
-	  rb2 = new JRadioButton("SkeletonCDF");
-	  rb2.setMnemonic('2');
-	  rb2.setToolTipText("<html><center>"+
-                             "Run the command-line based SkeletonCDF Tool Program."+
-                             "<br>"+
-                             "Need to define CDF_BASE environment variable."+
-                             "</center></html>");
-	  rb2.setActionCommand(skeletoncdf);
-	  rb2.addActionListener(this);
-	  buttonGroup.add(rb2);
+	rb3 = new JRadioButton("CDFConvert");
+	rb3.setMnemonic('3');
+	rb3.setToolTipText("<html><center>"+
+                           "Run the command-line based CDFConvert Tool Program."+
+                           "<br>"+
+                           "Need to define CDF_BASE environment variable."+
+                           "</center></html>");
+	rb3.setActionCommand(cdfconvert);
+	rb3.addActionListener(this);
+	buttonGroup.add(rb3);
 
-	  rb3 = new JRadioButton("CDFConvert");
-	  rb3.setMnemonic('3');
-	  rb3.setToolTipText("<html><center>"+
-                             "Run the command-line based CDFConvert Tool Program."+
-                             "<br>"+
-                             "Need to define CDF_BASE environment variable."+
-                             "</center></html>");
-	  rb3.setActionCommand(cdfconvert);
-	  rb3.addActionListener(this);
-	  buttonGroup.add(rb3);
+	rb4 = new JRadioButton("CDFCompare");
+	rb4.setMnemonic('4');
+	rb4.setToolTipText("<html><center>"+
+                           "Run the command-line based CDFCompare Tool Program."+
+                           "<br>"+
+                           "Need to define CDF_BASE environment variable."+
+                           "</center></html>");
+	rb4.setActionCommand(cdfcompare);
+	rb4.addActionListener(this);
+	buttonGroup.add(rb4);
 
-	  rb4 = new JRadioButton("CDFCompare");
-	  rb4.setMnemonic('4');
-	  rb4.setToolTipText("<html><center>"+
-                             "Run the command-line based CDFCompare Tool Program."+
-                             "<br>"+
-                             "Need to define CDF_BASE environment variable."+
-                             "</center></html>");
-	  rb4.setActionCommand(cdfcompare);
-	  rb4.addActionListener(this);
-	  buttonGroup.add(rb4);
+	rb5 = new JRadioButton("CDFInquire");
+	rb5.setMnemonic('5');
+	rb5.setToolTipText("<html><center>"+
+                           "Run the command-line based CDFInquire Tool Program."+
+                           "<br>"+
+                           "Need to define CDF_BASE environment variable."+
+                           "</center></html>");
+	rb5.setActionCommand(cdfinquire);
+	rb5.addActionListener(this);
+	buttonGroup.add(rb5);
 
-	  rb5 = new JRadioButton("CDFInquire");
-	  rb5.setMnemonic('5');
-	  rb5.setToolTipText("<html><center>"+
-                             "Run the command-line based CDFInquire Tool Program."+
-                             "<br>"+
-                             "Need to define CDF_BASE environment variable."+
-                             "</center></html>");
-	  rb5.setActionCommand(cdfinquire);
-	  rb5.addActionListener(this);
-	  buttonGroup.add(rb5);
+        rb6 = new JRadioButton("CDFStats");
+        rb6.setMnemonic('6');
+        rb6.setToolTipText("<html><center>"+
+                           "Run the command-line based CDFStats Tool Program."+
+                           "<br>"+
+                           "Need to define CDF_BASE environment variable."+
+                           "</center></html>");
+        rb6.setActionCommand(cdfstats);
+        rb6.addActionListener(this);
+        buttonGroup.add(rb6);
 
-          rb6 = new JRadioButton("CDFStats");
-          rb6.setMnemonic('6');
-          rb6.setToolTipText("<html><center>"+
-                             "Run the command-line based CDFStats Tool Program."+
-                             "<br>"+
-                             "Need to define CDF_BASE environment variable."+
-                             "</center></html>");
-          rb6.setActionCommand(cdfstats);
-          rb6.addActionListener(this);
-          buttonGroup.add(rb6);
+        rb7 = new JRadioButton("CDFDump");
+        rb7.setMnemonic('7');
+        rb7.setToolTipText("<html><center>"+
+                           "Run the command-line based CDFDump Tool Program."+
+                           "<br>"+
+                           "Need to define CDF_BASE environment variable."+
+                           "</center></html>");
+        rb7.setActionCommand(cdfdump);
+        rb7.addActionListener(this);
+        buttonGroup.add(rb7);
 
-          rb7 = new JRadioButton("CDFDump");
-          rb7.setMnemonic('7');
-          rb7.setToolTipText("<html><center>"+
-                             "Run the command-line based CDFDump Tool Program."+
-                             "<br>"+
-                             "Need to define CDF_BASE environment variable."+
-                             "</center></html>");
-          rb7.setActionCommand(cdfdump);
-          rb7.addActionListener(this);
-          buttonGroup.add(rb7);
+        rb8 = new JRadioButton("CDFDir");
+        rb8.setMnemonic('8');
+        rb8.setToolTipText("<html><center>"+
+                           "Run the command-line based CDFDir Tool Program."+
+                           "<br>"+
+                           "Need to define CDF_BASE environment variable."+
+                           "</center></html>");
+        rb8.setActionCommand(cdfdir);
+        rb8.addActionListener(this);
+        buttonGroup.add(rb8);
 
-          rb8 = new JRadioButton("CDFDir");
-          rb8.setMnemonic('8');
-          rb8.setToolTipText("<html><center>"+
-                             "Run the command-line based CDFDir Tool Program."+
-                             "<br>"+
-                             "Need to define CDF_BASE environment variable."+
-                             "</center></html>");
-          rb8.setActionCommand(cdfdir);
-          rb8.addActionListener(this);
-          buttonGroup.add(rb8);
+        rbb = new JRadioButton("CDFMerge");
+        rbb.setMnemonic('b');
+        rbb.setToolTipText("<html><center>"+
+                           "Run the command-line based CDFMerge Tool Program."+
+                           "<br>"+
+                           "Need to define CDF_BASE environment variable."+
+                           "</center></html>");
+        rbb.setActionCommand(cdfmerge);
+        rbb.addActionListener(this);
+        buttonGroup.add(rbb);
 
-          rbb = new JRadioButton("CDFMerge");
-          rbb.setMnemonic('b');
-          rbb.setToolTipText("<html><center>"+
-                             "Run the command-line based CDFmerge Tool Program."+
-                             "<br>"+
-                             "Need to define CDF_BASE environment variable."+
-                             "</center></html>");
-          rbb.setActionCommand(cdfmerge);
-          rbb.addActionListener(this);
-          buttonGroup.add(rbb);
-
-	}
+        rbc = new JRadioButton("CDFValidate");
+        rbc.setMnemonic('c');
+        rbc.setToolTipText("<html><center>"+
+                           "Run the command-line based CDFValidate Tool Program."+
+                           "<br>"+
+                           "Need to define CDF_BASE environment variable."+
+                           "</center></html>");
+        rbc.setActionCommand(cdfvalidate);
+        rbc.addActionListener(this);
+        buttonGroup.add(rbc);
 
         rb9 = new JRadioButton("CDFEdit");
         rb9.setMnemonic('9');
@@ -363,21 +379,16 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
         non = new JRadioButton("None");
         buttonGroup.add(non);
 
-//        if (((osName.indexOf("Mac") == -1) || (osName.indexOf("Mac OS X") != -1)) &&     
-//            osName.indexOf("Windows") == -1) {
-        if (((osName.indexOf("Mac") == -1) || (osName.indexOf("Mac OS X") != -1))) { 
-
-//	if (osName.indexOf("Mac") == -1 && osName.indexOf("Windows") == -1) {
-	  panel1.add(rb1);
-	  panel1.add(rb2);
-	  panel1.add(rb3);
-	  panel1.add(rb4);
-	  panel1.add(rb5);
-	  panel1.add(rb6);
-	  panel1.add(rb7);
-          panel1.add(rb8);
-          panel1.add(rbb);
-	}
+	panel1.add(rb1);
+	panel1.add(rb2);
+	panel1.add(rb3);
+	panel1.add(rb4);
+	panel1.add(rb5);
+	panel1.add(rb6);
+	panel1.add(rb7);
+        panel1.add(rb8);
+        panel1.add(rbb);
+	panel1.add(rbc);
 	panel1.add(rb9);
 	panel1.add(rba);
 	panel1.add(Box.createRigidArea(vpad5));
@@ -557,7 +568,7 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
             tf.setText("CDF_BASE environment variable has not been defined...");
             Toolkit.getDefaultToolkit().beep();
           } else {
-            if (threaddir == null) {
+            if (threadmerge == null) {
               tf.setText("Loading...");
               new ClearInfo(tf).start();
               pgmmerge = new CDFMerge(theDriver.getFrame(), cdfbase);
@@ -568,6 +579,22 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
             }
           }
           new ResetButton().start();
+        } else if (pgm.equals("CDFValidate")) {
+          if (osName.toLowerCase().indexOf("windows") == -1 && cdfbase == null) {
+            tf.setText("CDF_BASE environment variable has not been defined...");
+            Toolkit.getDefaultToolkit().beep();
+          } else {
+            if (threadvalidate == null) {
+              tf.setText("Loading...");
+              new ClearInfo(tf).start();
+              pgmvalidate = new CDFValidate(theDriver.getFrame(), cdfbase);
+              threadvalidate = new Thread(pgmvalidate);
+              threadvalidate.start();
+            } else {
+              pgmvalidate.reEnter();
+            }
+          }
+          new ResetButton().start();
 	} else if (pgm.equals("CDFEdit")) {
           if (threadedit == null) {
 	    tf.setText("Loading...");
