@@ -1,4 +1,4 @@
-// $Id: MYEditor.java,v 1.1.1.1 2009/01/20 16:27:23 liu Exp $
+// $Id: MYEditor.java,v 1.1.1.1 2010/01/13 20:06:14 liu Exp $
 
 import javax.swing.*;
 import javax.swing.event.*;
@@ -37,8 +37,11 @@ public class MYEditor extends JDialog implements CDFConstants {
     public JDialog frame;
 
     // The width and height of the frame
-    public static int Width = 800;
-    public static int Height = 640;
+//    public static int Width = 800;
+//    public static int Height = 640;
+    private int Width;
+    private int Height;
+
     public static int INITIAL_WIDTH = 300;
     public static int INITIAL_HEIGHT = 100;
 
@@ -156,7 +159,11 @@ public class MYEditor extends JDialog implements CDFConstants {
 	// Add the tab to the center
 	jp.add(tabbedPane, BorderLayout.CENTER);
 
-	// Global Attribute Pane
+        screenSize = Toolkit.getDefaultToolkit().getScreenSize();
+        Width = screenSize.width * 3 / 4;
+        Height = screenSize.height * 2 / 3;
+
+  	// Global Attribute Pane
 	gAttrPanel = new AttributePanel(this, GLOBAL_SCOPE);
 	tabbedPane.addTab("Global Attributes", null, gAttrPanel, 
 			  "Global Attributes display/editing");
@@ -311,8 +318,7 @@ public class MYEditor extends JDialog implements CDFConstants {
 	});
 
 	// show the frame
-	frame.setSize(Width, Height);
-	screenSize = Toolkit.getDefaultToolkit().getScreenSize();
+        frame.setSize(Width, Height);
 	frame.setLocation(screenSize.width/2 - Width/2,
 			  screenSize.height/2 - Height/2);
 	frame.getContentPane().setLayout(new BorderLayout());
@@ -339,6 +345,14 @@ public class MYEditor extends JDialog implements CDFConstants {
 	return cdfedit;
     }
 
+    public int getEditWidth() {
+        return Width;
+    }
+
+    public int getEditHeight() {
+        return Height;
+    }
+
     ////////////////////////////////////////////////////////////
     //                                                        //
     //                File Handling Methods                   //
