@@ -211,8 +211,8 @@ public class SkeletonCDF extends JFrame
     }
 
     SkeletonCDF(JFrame parentDriver, String cdfbase, boolean modal) {
-        if (cdfbase != null) command = cdfbase + separator + "bin" + 
-				       separator + "skeletoncdf ";
+        if (cdfbase != null) command = "\"" + cdfbase + separator + "bin" + 
+				       separator + "skeletoncdf\" ";
         dialog = new JDialog(this, modal);
 	this.parentDriver = parentDriver;
         this.modal = modal;
