@@ -1,4 +1,4 @@
-// $Id: VariablePanel.java,v 1.1.1.1 2009/01/20 16:27:23 liu Exp $
+// $Id: VariablePanel.java,v 1.1.1.1 2010/01/13 20:06:14 liu Exp $
 
 // Swing Imports
 import javax.swing.*;
@@ -115,8 +115,8 @@ public class VariablePanel extends JSplitPane
 	setDividerSize(5);
 
 	// Provide a preferred size for the split pane
-	setPreferredSize(new Dimension(MYEditor.Width, 
-                                       MYEditor.Height));
+	setPreferredSize(new Dimension(myEditor.getEditWidth(), 
+                                       myEditor.getEditHeight()));
 
 	resetPanel(false);
     }
