@@ -1,4 +1,4 @@
-//$Id: VariableValuePanel.java,v 1.1.1.1 2009/01/20 16:27:23 liu Exp $
+//$Id: VariableValuePanel.java,v 1.2 2011/01/14 18:14:54 liu Exp $
 
 // Swing Imports
 import javax.swing.*;
@@ -67,20 +67,20 @@ public class VariableValuePanel extends JLabeledPanel implements CDFConstants,
     static final long serialVersionUID = 1L;
 
     public VariableValuePanel(VariablePanel myVP) {
-	super("Edit Data", BorderFactory.createEtchedBorder(),
+        super("Edit Data", BorderFactory.createEtchedBorder(),
               TitledBorder.CENTER, TitledBorder.TOP,
-              new GridBagLayout());
-	setSize(670, 20);
+              new FlowLayout());
+        setSize(720, 20);
 
 	values = this;
 	this.myVP = myVP;
 	myEditor = myVP.getMyEditor();
 	cdf = myEditor.theCDF;
-	
-	jtfRec = new JLabeledTF("Record", 5);
+
+	jtfRec = new JLabeledTF("Record", 10);
 	jtfRec.textField.setHorizontalAlignment(JTextField.RIGHT);
 	oldRec = new JTextField();
-
+	add(jtfRec);
 	jpIndex = new JLabeledPanel("Index", BorderFactory.createEmptyBorder(),
 				    TitledBorder.CENTER, TitledBorder.TOP,
 				    new FlowLayout());
@@ -93,40 +93,33 @@ public class VariableValuePanel extends JLabeledPanel implements CDFConstants,
 	jtfIndex0.setHorizontalAlignment(JTextField.RIGHT);
 	jtfIndex1.setHorizontalAlignment(JTextField.RIGHT);
 	jtfIndex2.setHorizontalAlignment(JTextField.RIGHT);
+	add(jpIndex);
 
 	jtfVal = new JLabeledTF("Data Value", 32);
 	jtfVal.textField.getDocument().addDocumentListener(this);
 	jtfVal.textField.addFocusListener(this);
-	
+	add(jtfVal);
+
+	add(Box.createRigidArea(new Dimension(18, 8)));
+
+	JPanel jjj = new JPanel();
         update = new JButton(UPDATE) {
           static final long serialVersionUID = 1L;
-	  // deprecated - public boolean isFocusTraversable() { return false; }
-	  public boolean isFocusable() { return false; }
-	};
+          // deprecated - public boolean isFocusTraversable() { return false; }
+          public boolean isFocusable() { return false; }
+        };
 	update.setToolTipText("Click to apply change to the Variable's value");
         update.addActionListener( this );
 	update.setEnabled(false);
-	update.setSize(10,10);
+	add(update);
 
         cancel = new JButton(CANCEL) {
-          static final long serialVersionUID = 1L;
-          // Deprecated - public boolean isFocusTraversable() { return false; }
-          public boolean isFocusable() { return false; }
+          public boolean isFocusTraversable() { return false; }
         };
         cancel.setToolTipText("Click to cancel change to the Variable's value");
         cancel.addActionListener( this );
         cancel.setEnabled(false);
-	cancel.setSize(10,10);
-
-        makeJButton(values, jtfRec, 0, 0, 1, 1, 1.0, 1.0);
-	makeJButton(values, Box.createRigidArea(new Dimension(2,1)), 1, 0, 1, 1, 1.0, 1.0);
-	makeJButton(values, jpIndex, 2, 0, 1, 1, 1.0, 1.0);
-	makeJButton(values, Box.createRigidArea(new Dimension(2,1)), 3, 0, 1, 1, 1.0, 1.0);
-	makeJButton(values, jtfVal, 4, 0, 1, 1, 1.0, 1.0);
-	makeJButton(values, Box.createRigidArea(new Dimension(5,1)), 5, 0, 1, 1, 1.0, 1.0);
-        makeJButton(values, update, 6, 0, 1, 1, 1.0, 1.0);
-	makeJButton(values, Box.createRigidArea(new Dimension(5,1)), 7, 0, 1, 1, 1.0, 1.0);
-        makeJButton(values, cancel, 8, 0, 1, 1, 1.0, 1.0);
+	add(cancel);
 
 	values.setVisible(false);	
     }
@@ -187,9 +180,7 @@ public class VariableValuePanel extends JLabeledPanel implements CDFConstants,
             for (int i = 0; i < (int) nDims; i++) {
 		final long dimV = dimVars[i];
 		jtfIndex[i] = new JTextField(4) {
-                  static final long serialVersionUID = 1L;
-		  // Deprecated - public boolean isFocusTraversable() { 
-		  public boolean isFocusable() { 
+		  public boolean isFocusTraversable() { 
 		    if (dimV == VARY) return true;
 		    else return false; 
 		  }
@@ -631,7 +622,6 @@ public class VariableValuePanel extends JLabeledPanel implements CDFConstants,
             if (nDims > 0) {
               for (int i = 0; i < nDims; i++) {
                 if (dimVars[i] == VARY) {
-		  // Deprecated - jtfRec.textField.setNextFocusableComponent(jtfIndex[i]);
 		  jtfRec.textField.setNextFocusableComponent(jtfIndex[i]);
                   nomore = true;
                   break;
@@ -679,30 +669,5 @@ public class VariableValuePanel extends JLabeledPanel implements CDFConstants,
 	return recNum;
     }
 
-/** Set up gridbaglayout
- */
-
-    private void makeJButton(Container cont, Object arg,
-            int x, int y, int w, int h, double weightx, double weighty) {
-        GridBagLayout gbl = (GridBagLayout)cont.getLayout();
-        GridBagConstraints c = new GridBagConstraints();
-        Component comp;
-
-        c.fill = GridBagConstraints.BOTH;
-        c.gridx = x;
-        c.gridy = y;
-        c.gridwidth = w;
-        c.gridheight = h;
-        c.weightx = weightx;
-        c.weighty = weighty;
-        if (arg instanceof String) {
-            comp = new JButton((String)arg);
-        } else {
-            comp = (Component)arg;
-        }
-        cont.add(comp);
-        gbl.setConstraints(comp, c);
-    }
-
 }
 
