@@ -13,84 +13,96 @@ import gsfc.nssdc.cdf.util.*;
 public class ReadCDF implements CDFConstants{
 
     public static void main(String[] args) {
-        String  fileName = "test";
-        int     maxVarNameLength = 22;
+      String  fileName = "test";
+      int     maxVarNameLength = 22;
+      int ii, jj;
+      CDF cdf;
 
+      jj = args.length;
+      if (jj == 0) jj = 1;
+/*
+      try {
+        CDF.setValidate (VALIDATEFILEoff);
+      } catch (CDFException vax) {
+        System.out.println("*** Error at setting the validation..."+vax);
+        System.exit(1);
+      }
+*/
+      for (ii = 0; ii < jj; ++ii) {
+	if (args.length != 0) fileName = args[ii];
+        if (ii > 0) 
+          System.out.println("");
+        System.out.println("Reading " + fileName + "...:\n");
         try {
-            CDF cdf = null; 
-            if (args.length == 0) {
-                cdf  = CDF.open(fileName, READONLYon);
-            }
-            else {
-                fileName = args[0];
-                cdf = CDF.open(fileName, READONLYon);
-            }
+	  cdf = null;
+          cdf = CDF.open(fileName, READONLYon);
+          if (cdf.getStatus() != CDF_OK)
+          {
+            if (cdf.getStatus() == CHECKSUM_ERROR)
+              System.out.println("*** Checksum failed... the cdf file is corrupted...\n");
+              if (cdf != null) cdf.close();
+          } else {
 
-	    if (cdf.getStatus() != CDF_OK)
-	    {
-	      if (cdf.getStatus() == CHECKSUM_ERROR)
-	        System.out.println("*** Checksum failed... the cdf file is corrupted...\n");
-	      cdf.close();
-	      System.exit(1);
-	    }
+              /************************************************************/
+              /* If a decoding method is not specified when a CDF file is */
+              /* opened, the CDF libaray knows what encoding method was   */
+              /* used to create the CDF file.                             */
+              /*                                                          */
+              /* Decoding method should be specified only if one needs    */
+              /* to translate data from one platform to another.          */ 
+              /************************************************************/
+              // cdf.selectDecoding(NETWORK_DECODING);
 
-            /************************************************************/
-            /* If a decoding method is not specified when a CDF file is */
-            /* opened, the CDF libaray knows what encoding method was   */
-            /* used to create the CDF file.                             */
-            /*                                                          */
-            /* Decoding method should be specified only if one needs    */
-            /* to translate data from one platform to another.          */ 
-            /************************************************************/
-            // cdf.selectDecoding(NETWORK_DECODING);
+              /**********************************/
+              /* Print out the file information */
+              /**********************************/
+              System.out.println("File Info\n"+
+                                 "=========================================");
 
-            /**********************************/
-            /* Print out the file information */
-            /**********************************/
-            System.out.println("File Info\n"+
-                               "=========================================");
-
-            if (cdf.confirmReadOnlyMode() == READONLYon)
+              if (cdf.confirmReadOnlyMode() == READONLYon)
                 System.out.println("CDF File:     "+cdf+" (READONLYon)");
-            else {
+              else {
                 System.out.println("CDF File:     "+cdf+" (READONLYoff)");
-            }
+              }
 
-            System.out.println("Version:      "+cdf.getVersion());
-            String cp = cdf.getCopyright();
-            System.out.println("Copyright:    "+cp);
-            System.out.println("Format:       "+CDFUtils.getStringFormat(cdf));
-            System.out.println("Encoding:     "+
-                               CDFUtils.getStringEncoding(cdf));
-            System.out.println("Decoding:     "+
-                               CDFUtils.getStringDecoding(cdf));
-            System.out.println("Majority:     "+
-                               CDFUtils.getStringMajority(cdf));
-            System.out.println("Checksum:     "+
-                               CDFUtils.getStringChecksum(cdf));
-            System.out.println("numRvars:     "+cdf.getNumRvars());
-            System.out.println("numZvars:     "+cdf.getNumZvars());
-            System.out.println("numAttrs:     "+cdf.getNumAttrs()+
-                               " ("+cdf.getNumGattrs()+" global, "+
-                               cdf.getNumVattrs()+" variable)");
-            System.out.println("Compression:  "+cdf.getCompression());
-            if (cdf.getCompressionType() != 0)
-              System.out.println("cPct:         "+cdf.getCompressionPct());
-            System.out.println("Cache Size:   "+cdf.confirmCDFCacheSize());
-
-            /**********************************************/
-            /* Print out the Global Attribute information */
-            /**********************************************/
-            Attribute a;
-            String    attrName = null;
-            int       i;
-            long      n = cdf.getNumGattrs();
-            Vector    ga = cdf.getGlobalAttributes();
-         
-            System.out.println("\nGlobal Attributes ("+n+" attributes)\n"+
-                               "=========================================");
-            i = 0;
-            for (Enumeration e = ga.elements() ; e.hasMoreElements() ;) {
+              System.out.println("Version:      "+cdf.getVersion());
+              String cp = cdf.getCopyright();
+              System.out.println("Copyright:    "+cp);
+              System.out.println("Format:       "+CDFUtils.getStringFormat(cdf));
+              System.out.println("Encoding:     "+
+                                 CDFUtils.getStringEncoding(cdf));
+              System.out.println("Decoding:     "+
+                                 CDFUtils.getStringDecoding(cdf));
+              System.out.println("Majority:     "+
+                                 CDFUtils.getStringMajority(cdf));
+              if (cdf.getMajority() == COLUMN_MAJOR)
+                System.out.println("(********  Data dumps from multi-dimensional "+
+                                   "variables are shown row-based.)"); 
+              System.out.println("Checksum:     "+
+                                 CDFUtils.getStringChecksum(cdf));
+              System.out.println("numRvars:     "+cdf.getNumRvars());
+              System.out.println("numZvars:     "+cdf.getNumZvars());
+              System.out.println("numAttrs:     "+cdf.getNumAttrs()+
+                                 " ("+cdf.getNumGattrs()+" global, "+
+                                 cdf.getNumVattrs()+" variable)");
+              System.out.println("Compression:  "+cdf.getCompression());
+              if (cdf.getCompressionType() != 0)
+                System.out.println("cPct:         "+cdf.getCompressionPct());
+              System.out.println("Cache Size:   "+cdf.confirmCDFCacheSize());
+  
+              /**********************************************/
+              /* Print out the Global Attribute information */
+              /**********************************************/
+              Attribute a;
+              String    attrName = null;
+              int       i;
+              long      n = cdf.getNumGattrs();
+              Vector    ga = cdf.getGlobalAttributes();
+           
+              System.out.println("\nGlobal Attributes ("+n+" attributes)\n"+
+                                 "=========================================");
+              i = 0;
+              for (Enumeration e = ga.elements() ; e.hasMoreElements() ;) {
                 a = (Attribute) e.nextElement();
                 n = a.getNumEntries(); 
                 if (i == 0) {
@@ -135,19 +147,19 @@ public class ReadCDF implements CDFConstants{
                     }
                 }
                 System.out.println (" ");
-            }
+              }
 
-            /************************************************/
-            /* Print out the Variable Attribute information */
-            /************************************************/
-            attrName = null;
-            n = cdf.getNumVattrs();
-            Vector  va = cdf.getVariableAttributes();
+              /************************************************/
+              /* Print out the Variable Attribute information */
+              /************************************************/
+              attrName = null;
+              n = cdf.getNumVattrs();
+              Vector  va = cdf.getVariableAttributes();
 
-            System.out.println("\nVariable Attributes ("+n+" attributes)\n"+
+              System.out.println("\nVariable Attributes ("+n+" attributes)\n"+
                                "=========================================");
-            i = 0;
-            for (Enumeration e = va.elements() ; e.hasMoreElements() ;) {
+              i = 0;
+              for (Enumeration e = va.elements() ; e.hasMoreElements() ;) {
                 a = (Attribute) e.nextElement();
                 if (i == 0) {
                     attrName = a.getName();
@@ -182,22 +194,22 @@ public class ReadCDF implements CDFConstants{
                     }
                 }
                 System.out.println (" ");
-            }
+              }
 
-            /**************************************/
-            /* Print out the Variable information */ 
-            /**************************************/
-            String  varName, dataType;
-            int     noOfBlanks;
-            long    dt, numDims, blockingFactor;
-            Object  padValue = null;
+              /**************************************/
+              /* Print out the Variable information */ 
+              /**************************************/
+              String  varName, dataType;
+              int     noOfBlanks;
+              long    dt, numDims, blockingFactor;
+              Object  padValue = null;
 
-            n = cdf.getNumVars();
-            Vector  vars = cdf.getVariables();
+              n = cdf.getNumVars();
+              Vector  vars = cdf.getVariables();
 
-            System.out.println("\nVariable Information ("+n+" variables)\n"+
-                               "=========================================");
-            for (Enumeration e = vars.elements() ; e.hasMoreElements() ;) {
+              System.out.println("\nVariable Information ("+n+" variables)\n"+
+                                 "=========================================");
+              for (Enumeration e = vars.elements() ; e.hasMoreElements() ;) {
                 Variable v = (Variable) e.nextElement();
 
                 varName = v.getName();
@@ -248,21 +260,21 @@ public class ReadCDF implements CDFConstants{
                     System.out.print (" blockingFactor=\""+blockingFactor+"\"");
 
                 System.out.println (" ");
-            }
+              }
 
-            /**********************************************************/
-            /* Print out the Variable data (all variables in the CDF) */ 
-            /**********************************************************/
-            System.out.println("\n\nVariable Data ("+n+" variables)\n"+
-                               "=========================================");
-            CDFData data = null;
-            long   numRecs, maxRec;
-            long[] dimIndices   = {0L};
-            long[] dimIntervals = {1L};
-            long[] dimSizes     = {1L};
+              /**********************************************************/
+              /* Print out the Variable data (all variables in the CDF) */ 
+              /**********************************************************/
+              System.out.println("\n\nVariable Data ("+n+" variables)\n"+
+                                 "=========================================");
+              CDFData data = null;
+              long   numRecs, maxRec;
+              long[] dimIndices   = {0L};
+              long[] dimIntervals = {1L};
+              long[] dimSizes     = {1L};
 
-            for (Enumeration e = vars.elements() ; e.hasMoreElements() ;) {
-                Variable v = (Variable) e.nextElement();
+              for (Enumeration e = vars.elements() ; e.hasMoreElements() ;) {
+                  Variable v = (Variable) e.nextElement();
 
                 if (v.getNumDims() > 0) {
                     dimSizes = v.getDimSizes();
@@ -336,22 +348,22 @@ public class ReadCDF implements CDFConstants{
                      else
                          System.out.println("    <virtual>\n");
                 }
-            }
+              }
 
-            /**************************************************/
-            /*  Print out a few individual variable data and  */
-            /*  attribute entries.                            */
-            /**************************************************/
-            if (fileName.equals("test")) {
-               System.out.println("\n\nIndividual Variable Data\n"+
+              /**************************************************/
+              /*  Print out a few individual variable data and  */
+              /*  attribute entries.                            */
+              /**************************************************/
+              if (fileName.equals("test")) {
+                System.out.println("\n\nIndividual Variable Data\n"+
                                    "=================================");
 
-               Variable longitude = cdf.getVariable("Longitude"),   /* T/T */
-                        latitude  = cdf.getVariable("Latitude"),    /* F/T */
-                        latitude1 = cdf.getVariable("Latitude1"),   /* T/F */
-                        time      = cdf.getVariable("Time"),        /* T/T */
-                        foo       = cdf.getVariable("foo"),         /* F/F */
-                        v         = cdf.getVariable("longitude_dup");
+                Variable longitude = cdf.getVariable("Longitude"),   /* T/T */
+                         latitude  = cdf.getVariable("Latitude"),    /* F/T */
+                         latitude1 = cdf.getVariable("Latitude1"),   /* T/F */
+                         time      = cdf.getVariable("Time"),        /* T/T */
+                         foo       = cdf.getVariable("foo"),         /* F/F */
+                         v         = cdf.getVariable("longitude_dup");
 
                 System.out.println ("longDup.dumpData():");
                 System.out.println ("------------------");
@@ -426,7 +438,7 @@ public class ReadCDF implements CDFConstants{
                long[][]  yy = (long [][]) time.getRecord(0L); 
                for (int x=0;x<3; x++)
                  for (int j=0;j<2;j++)
-                      System.out.println("["+x+","+j+"] ="+yy[x][j]);
+                      System.out.println("["+x+","+j+"] = "+yy[x][j]);
 
                System.out.println ("\n");
 
@@ -465,7 +477,7 @@ public class ReadCDF implements CDFConstants{
                  System.out.println ("\nRecord #"+x+":");
                  for (int j=0;j<3;j++) {
                    for (int k=0;k<2;k++) 
-                        System.out.println("["+j+","+k+"] ="+xxx[x][j][k]);
+                        System.out.println("["+j+","+k+"] = "+xxx[x][j][k]);
                  }
                }
 
@@ -484,10 +496,28 @@ public class ReadCDF implements CDFConstants{
                                      " (2nd and 3rd row of the 3x2 array):");
                  for (int j=0;j<2;j++) {
                    for (int k=0;k<2;k++) 
-                        System.out.println("["+(j+1)+","+k+"] ="+xx[x][j][k]);
+                        System.out.println("["+(j+1)+","+k+"] = "+xx[x][j][k]);
                  }
                }
 
+               /******************************************************/
+               /*  Read the 1st column of the 3x2 array in the       */
+               /*  1st and the 2nd record.                           */
+               /******************************************************/
+               int[][] xx1 = (int [][]) var.getHyperData (0L, 2L, 1L, 
+                                                          new long[] {0, 0},
+                                                          new long[] {3, 1},
+                                                          new long[] {1, 1});
+               for (int x=0; x < 2; x++) {
+                 int recNo = x;
+                 if (x == 1) recNo = 1;
+                 System.out.println ("\nRecord #"+recNo+
+                                     " (1st column of the 3x2 array):");
+                 for (int j=0; j < 3; j++) 
+                    System.out.println("["+j+",0] = "+xx1[x][j]);
+               }
+               System.out.println ("\n");
+
                /*************************************************************/
                /* Initiate a record read for a group of CDF variables.      */ 
                /* Five (5) variables are involved in this data get function */
@@ -507,8 +537,8 @@ public class ReadCDF implements CDFConstants{
 	       record = cdf.getRecord(5L, strVars, status);
 	       /* record = cdf.getRecord(5L, varIDs, status);    */
 
-	       System.out.println ("\nDump of the 6th record (Longitude1, "+
-                                   "Temp1, dp, Temp, Temperature):");
+	       System.out.println ("\nDump of the 6th record from \"Longitude1, "+
+                                   "Temp1, dp, Temp, Temperature\":");
 
                /* var: Longitude1 -- CDF_UINT2, dimensionality: 1:[3] */
 	       System.out.print ("    Longitude1 -- "); 
@@ -539,25 +569,6 @@ public class ReadCDF implements CDFConstants{
                System.out.print (record.elementAt(4)+" ");
                System.out.println ("");
 
-               /******************************************************/
-               /*  Read the 1st column of the 3x2 array in the       */
-               /*  1st and the 2nd record.                           */
-               /******************************************************/
-               int[][] xx1 = (int [][]) var.getHyperData (0L, 2L, 1L, 
-                                                          new long[] {0, 0},
-                                                          new long[] {3, 1},
-                                                          new long[] {1, 1});
-               for (int x=0; x < 2; x++) {
-                 int recNo = x;
-                 if (x == 1) recNo = 1;
-                 System.out.println ("\nRecord #"+recNo+
-                                     " (1st column of the 3x2 array):");
-                 for (int j=0; j < 3; j++) 
-                    System.out.println("["+j+",0] ="+xx1[x][j]);
-               }
-               System.out.println ("\n");
-                                 
-
                System.out.println("\n\nVariable/Global Attribute Entries"+
                                   "\n====================================");
 
@@ -586,9 +597,10 @@ public class ReadCDF implements CDFConstants{
             }
 
             cdf.close();
-
+          }
         } catch (Exception e) {
-             System.out.println (e);
+           System.out.println (e);
         }
+      }
     }
 }
