@@ -1,4 +1,4 @@
-// $Id: Attribute.java,v 1.1.1.1 2009/01/20 16:27:22 liu Exp $
+// $Id: Attribute.java,v 1.4 2011/11/21 19:58:11 liu Exp $
 package gsfc.nssdc.cdf;
 
 import java.util.*;
@@ -15,6 +15,8 @@ import java.io.File;
  *                        JNI call is synchronized so only one process is
  *                        allowed in a JVM, due to multi-thread safety.
  *                        The select method will never be called.
+ * @version 3.3 01/31/11  Reset the vector size to match the maximum entry in
+ *                        stead of its expanded capacity in getEntries method.
  * @author Phil Williams, QSS Group Inc/RITSS <BR>
  *         Mike Liu, RSTX 
  *
@@ -276,7 +278,6 @@ synchronized(myCDF) {
 	if (scope == VARIABLE_SCOPE)
 	    for (int i=0; i < (int)theAttr.myCDF.getNumVars(); i++)
 		theAttr.entries.addElement(null);
-
 	return theAttr;
     }
 }
@@ -550,10 +551,40 @@ synchronized(myCDF) {
      * only one entry for a particular attribute.
      *
      * @return all the entries (one or more) defined for a global attribute
-     *         or a variable entry for this attribute
+     *         or all variable entries for this attribute. The number of
+     *         returned entries vector for a variable attribute may be less
+     *         than the number of variables, as not all variables have an entry
+     *         for the attribute. 
+     *         
      */
-    public synchronized Vector getEntries() {
-
+     public synchronized Vector getEntries() throws CDFException {
+         Vector cmds = new Vector();
+         Vector item1 = new Vector();
+         Vector itemA = new Vector();
+         Vector itemB = new Vector();
+ 
+         cmds.addElement(new Long(SELECT_));
+            cmds.addElement(new Long(CDF_));
+               itemA.addElement("cdfID");
+               itemA.addElement("J");
+            cmds.addElement(itemA);
+            cmds.addElement(new Long(ATTR_));
+               itemB.addElement("id");
+               itemB.addElement("J");
+            cmds.addElement(itemB);
+ 
+         cmds.addElement(new Long(GET_));
+           cmds.addElement(((this.getScope() == GLOBAL_SCOPE) ?
+                            new Long(ATTR_MAXgENTRY_) :
+                            new Long(ATTR_MAXzENTRY_)));
+             item1.addElement("maxEntryNumber");
+             item1.addElement("J");
+           cmds.addElement(item1);
+         cmds.addElement(new Long(NULL_));
+ 
+         myCDF.executeCommand((CDFObject)this, cmds);
+ 
+	entries.setSize((int)maxEntryNumber+1); 
 	return entries;
 
     }
