@@ -23,15 +23,18 @@ public interface CDFConstants {
     /*---------*/
 
     public static final long CDF_VAR_NAME_LEN   = 64;
+    public static final long CDF_VAR_NAME_LEN256   = 256;
     public static final long CDF_ATTR_NAME_LEN  = 64;
+    public static final long CDF_ATTR_NAME_LEN256  = 256;
     public static final long CDF_COPYRIGHT_LEN  = 256;
     public static final long CDF_STATUSTEXT_LEN = 80;
-    public static final long CDF_PATHNAME_LEN   = 128;
+    public static final long CDF_PATHNAME_LEN   = 512;
 
     public static final long EPOCH_STRING_LEN   = 24;
     public static final long EPOCH1_STRING_LEN  = 16;
     public static final long EPOCH2_STRING_LEN  = 14;
     public static final long EPOCH3_STRING_LEN  = 24;
+    public static final long EPOCH4_STRING_LEN  = 23;
     public static final long EPOCHx_STRING_MAX  = 50;
     public static final long EPOCHx_FORMAT_MAX  = 68;
 
@@ -39,6 +42,7 @@ public interface CDFConstants {
     public static final long EPOCH1_STRING_LEN_EXTEND  = 24;
     public static final long EPOCH2_STRING_LEN_EXTEND  = 14;
     public static final long EPOCH3_STRING_LEN_EXTEND  = 36;
+    public static final long EPOCH4_STRING_LEN_EXTEND  = 32;
 
     /*----------------*/
     /* CDF data types */
@@ -72,7 +76,7 @@ public interface CDFConstants {
     public static final long IBMPC_ENCODING        =  6;
     public static final long IBMRS_ENCODING        =  7;
     public static final long HOST_ENCODING         =  8;
-    public static final long MAC_ENCODING          =  9;
+    public static final long PPC_ENCODING          =  9;
     public static final long HP_ENCODING           =  11;
     public static final long NeXT_ENCODING         =  12;
     public static final long ALPHAOSF1_ENCODING    =  13;
@@ -92,7 +96,9 @@ public interface CDFConstants {
     public static final long IBMPC_DECODING          = IBMPC_ENCODING;
     public static final long IBMRS_DECODING          = IBMRS_ENCODING;
     public static final long HOST_DECODING           = HOST_ENCODING;
-    public static final long MAC_DECODING            = MAC_ENCODING;
+    public static final long PPC_DECODING            = PPC_ENCODING;
+    public static final long MAC_ENCODING            = PPC_ENCODING;
+    public static final long MAC_DECODING            = PPC_ENCODING;
     public static final long HP_DECODING             = HP_ENCODING;
     public static final long NeXT_DECODING           = NeXT_ENCODING;
     public static final long ALPHAOSF1_DECODING      = ALPHAOSF1_ENCODING;
@@ -158,6 +164,13 @@ public interface CDFConstants {
     public static final long BACKWARDFILEoff = 0;
 
     /*---------------------*/
+    /* Validate modes */
+    /*---------------------*/
+
+    public static final long VALIDATEFILEon  = -1;
+    public static final long VALIDATEFILEoff = 0;
+
+     /*---------------------*/
     /* Checksum modes */
     /*---------------------*/
 
@@ -358,6 +371,7 @@ public interface CDFConstants {
     public static final long BAD_CHECKSUM                 = -2225;
     public static final long CHECKSUM_ERROR               = -2226;
     public static final long CHECKSUM_NOT_ALLOWED         = -2227;
+    public static final long IS_A_NETCDF                  = -2228;
 
     /*----------------------------------------------------------------*/
     /*  Functions (for INTERNAL interface).                           */
@@ -377,6 +391,8 @@ public interface CDFConstants {
     public static final long GETCDFFILEBACKWARD_ =      1011;
     public static final long CHECKSUM_ =                1012;
     public static final long GETCDFCHECKSUM_ =          1013;
+    public static final long VALIDATE_ =                1014;
+    public static final long GETCDFVALIDATE_ =          1015;
 
     public static final long NULL_ =			1000;
 
