@@ -1,4 +1,4 @@
-//$Id: CDFData.java,v 1.1.1.1 2009/01/20 16:27:22 liu Exp $
+//$Id: CDFData.java,v 1.2 2010/06/10 17:03:25 liu Exp $
 package gsfc.nssdc.cdf;
 
 import java.lang.*;
@@ -21,6 +21,11 @@ import gsfc.nssdc.cdf.*;
  *                        JNI call is synchronized so only one process is
  *                        allowed in a JVM, due to multi-thread safety.
  *                        The select method will never be called.
+ * @version 3.0 06/09/09  The number of dimesions returned from the get method
+ *                        depends on the variable dimensions and dimesional 
+ *                        elements: e.g., 2-dim (2x1 or 1x2) will have a 2-dim,
+ *                        not 1-dim, object returned, while 2-dim (1x1) 
+ *                        returns an object of a single item, not an array. 
  * @author Phil Williams, QSS Group Inc/RITSS <BR>
  *         Mike Liu, RSTX
  *
@@ -72,6 +77,37 @@ public class CDFData implements CDFObject, CDFConstants {
          return _dataArray; 
     }
 
+    /**
+     * Returns an object of a 1-dimensional array, which presents a sequence
+     * of raw data values retrieved and presented by JNI from a CDF file.
+     * The data stream may or may not reflect how the data is stored in the
+     * file, depending the file majority. It is up to the calling application
+     * to decipher the data stream. Note: for column-major CDF files, the 
+     * sequence of the returned data stream is reordered so data can be 
+     * properly assigned into Java's arrays. Normally, getData method
+     * should be called so the retrieved data are properly dimensioned.  <P>
+     *
+     * The following example retrieves the 2-D Temperature data.  The user
+     * should know how to organize the data, e.g., number of records, 
+     * row/column major, data type, data value sequence, etc. 
+     * <PRE>
+     *    Variable var = cdf.getVariable("Temperature");
+     *    CDFData data = var.getHyperDataObject (recNum,
+     *                                           recCount,
+     *                                           recInterval,
+     *                                           dimIndicies,
+     *                                           dimSizes,
+     *                                           dimCounts);
+     *    long[] temperature = (long []) data.getRawData();
+     * </PRE>
+     *
+     * @return a generic Object that is properly dimensioned
+     */
+    public Object getRawData() {
+
+         return _data;
+    }
+
     /**
      * Variable id. 
      */
@@ -99,6 +135,11 @@ public class CDFData implements CDFObject, CDFConstants {
      */
     private long numDims;
 
+    /**
+     * The dimension sizes for this variable.
+     */
+    private long[] varDimSizes;
+
      /**
      * Used in the JNI. This is the "real" signature of _data.
      */
@@ -277,6 +318,7 @@ public class CDFData implements CDFObject, CDFConstants {
 	dataType    = _myVar.getDataType();
 	numElements = _myVar.getNumElements();
 	numDims     = _myVar.getNumDims();
+        varDimSizes = _myVar.getDimSizes();
     }
 
     /**
@@ -320,8 +362,8 @@ synchronized(v) {
           theData.dimIntervals = dimIntervals;
         } else { // for 0 dimensional, we set it to dummy 1 dimensional
           theData.dimIndices   = new long[] {0L};
-          theData.dimCounts    = new long[] {0L};
-          theData.dimIntervals = new long[] {0L};
+          theData.dimCounts    = new long[] {1L};
+          theData.dimIntervals = new long[] {1L};
         }
 
 	// Determine the dimensionality and sizes of this data
@@ -340,7 +382,6 @@ synchronized(v) {
 
         // Create the 1D _data object
         theData.buildDataObject();
-
 	// Select the variable and the correct record etc.
 //        v.select(recStart, recCount, recInterval, dimIndices, 
 //		 dimCounts, dimIntervals);
@@ -582,7 +623,7 @@ synchronized(v) {
      */
     private void arrayify() throws CDFException {
 
-	if (nDims <= 1) {
+	if (nDims <= 1 || numValues == 1) {
 	    if ((dataType == CDF_CHAR) || (dataType == CDF_UCHAR)) {
 		if (nDims == 0)
 		    _dataArray = new String((byte [])_data);
@@ -627,11 +668,9 @@ synchronized(v) {
 	    int n = 0; // The current element in the _data
 	    Object cObject = _dataArray;  // A temp object to hold a subarray
 	    boolean boundaryCrossed;
-
 	    // Unwrap the 1D array to the multidimensional array.
 	    // Note that if the user wanted a 1D array then this will not
 	    // be used since _dataArray = _data
-
 	    while (n < numValues) {
 		// Get the correct 2D subarray to fill
 		if (n != 0) {
@@ -655,7 +694,6 @@ synchronized(v) {
 			}
 		    }
 		}
-
 		// Fill the rows of the 2D subarray
 		for (int i=0; i<dimSizes[(int)nDims-2]; i++) {
 		    switch ((int)_myVar.getDataType()) {
@@ -735,7 +773,7 @@ synchronized(v) {
      */
     private void vectorize() throws CDFException {
 
-	if (nDims <= 1)
+	if (nDims <= 1 || numValues == 1)
 	    if ((dataType == CDF_CHAR) || (dataType == CDF_UCHAR)) {
 		String dataClassName = _dataArray.getClass().getName();
 		if (dataClassName.indexOf("[B") == -1) {
@@ -903,7 +941,6 @@ synchronized(v) {
 	 */
 	if (_dataArray != null) {	// Called from put
 	    nDims = _dataArray.getClass().getName().lastIndexOf("[") + 1;
-
 	    // Is the _dataArray an array?
 	    if (_dataArray.getClass().isArray()) { 
 		tempArray = _dataArray;
@@ -923,12 +960,14 @@ synchronized(v) {
 	    nDims = ((recCount > 1) ? 1 : 0);
 	    int len = dimCounts.length;
 	    if (len == 1) {
-		if (dimCounts[0] > 1) 
+//		if (dimCounts[0] > 1) 
+              if (dimCounts[0] > 1 || (numDims > 0 && varDimSizes[0] == 1))
 		    nDims += 1;
 	    } else {
 		boolean multi=false;
 		for (int i=0; i<len; i++)
-		    if (dimCounts[i] > 1)
+//		    if (dimCounts[i] > 1)
+                  if (dimCounts[i] > 1 || varDimSizes[i] == 1)
 			nDims ++;
 	    }
 	    // Get the dimSizes
@@ -940,18 +979,20 @@ synchronized(v) {
 		    int j = 0;
 		    dimSizes[0] = (int)recCount;
 		    for (int i=0; i<numDims; i++) {
-			if (dimCounts[i] > 1) {
+//			if (dimCounts[i] > 1) {
+                      if (dimCounts[i] > 1 || varDimSizes[i] == 1) {
 			   j++;
 			   dimSizes[j] = (int)dimCounts[i];
-			}
+                      }
 		    }
 		} else {
 		    int j = -1;
 		    for (int i=0; i<numDims; i++) {
-			if (dimCounts[i] > 1) {
+//			if (dimCounts[i] > 1) {
+                      if (dimCounts[i] > 1 || varDimSizes[i] == 1) {
 			   j++;
 			   dimSizes[j] = (int)dimCounts[i];
-			}
+                      }
 		    }
 		}
 	    }
@@ -1236,8 +1277,8 @@ synchronized(v) {
         //                                                         //
         /////////////////////////////////////////////////////////////
 
-        if (nDims <= 1) {
-            if (nDims == 0) {
+        if (nDims <= 1 || numValues == 1) {
+            if (nDims == 0 || numValues == 1) {
                 if (_myVar.getDataType() == CDF_EPOCH) {
                     Double lEpoch = (Double) _dataArray;
                     System.out.println (Epoch.encode(lEpoch.doubleValue()));
@@ -1378,10 +1419,9 @@ synchronized(v) {
             int n = 0; // The current element in the _data
             Object cObject = _dataArray;  // A temp object to hold a subarray
             boolean boundaryCrossed;
-
             while (n < boundary[0]) {
                 // Get the correct 2D subarray to print
-                if (n!=0) {
+                if (n != 0) {
                     for (int i = 0; i < (int)nDims-1; i++) {
                         boundaryCrossed = ((n % boundary[i]) == 0);
                         if (boundaryCrossed) {
