@@ -1,4 +1,4 @@
-// $Id: CDFUtils.java,v 1.1.1.1 2009/01/20 16:27:22 liu Exp $
+// $Id: CDFUtils.java,v 1.4 2011/01/05 16:23:05 liu Exp $
 
 package gsfc.nssdc.cdf.util;
 
@@ -145,9 +145,10 @@ public class CDFUtils implements CDFConstants {
      *
      *  @param data the data to be printed
      *  @param which the Epoch data type data indicator
+     *  @param iso8601 the ISO 8601 indicator for EPOCH data
      *
      */
-    public static void printData (Object data, int which) {
+    public static void printData (Object data, int which, boolean iso8601) {
 
         int  i, arrayLength, jj = 1;
         String signature = CDFUtils.getSignature(data);
@@ -172,25 +173,47 @@ public class CDFUtils implements CDFConstants {
 
                  else if (signature.charAt(1) == 'D')
 		   if (which == 1) {
-		     System.out.print (Epoch.encode(Array.getDouble(data,i))+
+		     System.out.print (((!iso8601)?
+                                        Epoch.encode(Array.getDouble(data,i)):
+                                        Epoch.encode4(Array.getDouble(data,i)))+
                                        " ");
                    } else if (which == 2) {
                      double[] mmm = new double[2];
                      mmm[0] = Array.getDouble(data,i);
                      mmm[1] = Array.getDouble(data,i+1);
-                     System.out.print (Epoch16.encode(mmm)+" ");
+                     System.out.print (((!iso8601)?
+                                        Epoch16.encode(mmm):
+                                        Epoch16.encode4(mmm))+
+                                        (arrayLength==2?"":" "));
 		   } else
                      System.out.print (Array.getDouble(data,i)+" ");
             }
         }
         else {
 	   if (which == 1) 
-             System.out.print (Epoch.encode(((Double)data).doubleValue())+" ");
+             System.out.print (((!iso8601)?
+                                Epoch.encode(((Double)data).doubleValue()):
+                                Epoch.encode4(((Double)data).doubleValue())));
            else
              System.out.print (data);
 	}
     }
 
+
+    /**
+     *  Prints the value of the given data on the screen.  Data can be a
+     *  java primitive data type, Java Object (non-array), or
+     *  1-dimensional array of primitive Java data type.
+     *
+     *  @param data the data to be printed
+     *  @param which the Epoch data type data indicator
+     *
+     */
+    public static void printData (Object data, int which) {
+
+        CDFUtils.printData (data, which, false);
+    }
+
     /**
      *  Prints the value of the given data to the place designated by
      *  PrintWriter that can be a file, Sysem.out, System.err, and etc.  
@@ -216,11 +239,16 @@ public class CDFUtils implements CDFConstants {
      *                   of the object/data is printed as a text-output stream
      */
     public static void printData (Object data, PrintWriter outWriter) {
-	printData(data, outWriter, 0);
+	printData(data, outWriter, 0, false);
     }
 
     public static void printData (Object data, PrintWriter outWriter,
 				  int which) {
+        printData(data, outWriter, which, false);
+    }
+
+    public static void printData (Object data, PrintWriter outWriter,
+				  int which, boolean iso8601) {
 
         int  i, arrayLength, jj = 1;
         String signature = CDFUtils.getSignature(data);
@@ -246,13 +274,18 @@ public class CDFUtils implements CDFConstants {
 
                  else if (signature.charAt(1) == 'D') {
                      if (which == 1) {
-                       outWriter.print (Epoch.encode(Array.getDouble(data,i))+
+                       outWriter.print (((!iso8601)?
+                                         Epoch.encode(Array.getDouble(data,i)):
+                                         Epoch.encode4(Array.getDouble(data,i)))+
                                         " ");
                      } else if (which == 2) {
                        double[] mmm = new double[2];
                        mmm[0] = Array.getDouble(data,i);
                        mmm[1] = Array.getDouble(data,i+1);
-                       outWriter.print (Epoch16.encode(mmm)+" ");
+                       outWriter.print (((!iso8601)?
+                                         Epoch16.encode(mmm):
+                                         Epoch16.encode4(mmm))+
+                                         (arrayLength==2?"":" "));
                      } else
                        outWriter.print (Array.getDouble(data,i)+" ");
 		 }
@@ -260,7 +293,9 @@ public class CDFUtils implements CDFConstants {
         }
         else {
 	   if (which == 1)
-	     outWriter.print (Epoch.encode(((Double)data).doubleValue()));
+	     outWriter.print (((!iso8601)?
+                               Epoch.encode(((Double)data).doubleValue()):
+                               Epoch.encode4(((Double)data).doubleValue())));
            else
 	     outWriter.print (data);
 	}
@@ -714,7 +749,7 @@ public class CDFUtils implements CDFConstants {
      *             <LI>IBMPC_ENCODING
      *             <LI>IBMRS_ENCODING
      *             <LI>HOST_ENCODING
-     *             <LI>MAC_ENCODING
+     *             <LI>PPC_ENCODING
      *             <LI>HP_ENCODING
      *             <LI>NeXT_ENCODING
      *             <LI>ALPHAOSF1_ENCODING
@@ -733,7 +768,7 @@ public class CDFUtils implements CDFConstants {
      *             <LI>IBMPC
      *             <LI>IBMRS
      *             <LI>HOST
-     *             <LI>MAC
+     *             <LI>PPC
      *             <LI>HP
      *             <LI>NeXT
      *             <LI>ALPHAOSF1
@@ -748,7 +783,7 @@ public class CDFUtils implements CDFConstants {
                                "SUN",        "VAX", 
                                "DECSTATION", "SGi",
                                "IBMPC",      "IBMRS", 
-                               "HOST",       "MAC", 
+                               "HOST",       "PPC", 
                                " ",          "HP",
                                "NeXT",       "ALPHAOSF1",  
                                "ALPHAVMSd",  "ALPHAVMSg",  
@@ -776,7 +811,7 @@ public class CDFUtils implements CDFConstants {
      *             <LI>IBMPC
      *             <LI>IBMRS
      *             <LI>HOST
-     *             <LI>MAC
+     *             <LI>PPC
      *             <LI>HP
      *             <LI>NeXT
      *             <LI>ALPHAOSF1
@@ -795,7 +830,7 @@ public class CDFUtils implements CDFConstants {
      *             <LI>IBMPC_ENCODING
      *             <LI>IBMRS_ENCODING
      *             <LI>HOST_ENCODING
-     *             <LI>MAC_ENCODING
+     *             <LI>PPC_ENCODING
      *             <LI>HP_ENCODING
      *             <LI>NeXT_ENCODING
      *             <LI>ALPHAOSF1_ENCODING
@@ -810,7 +845,7 @@ public class CDFUtils implements CDFConstants {
                                "SUN",        "VAX",
                                "DECSTATION", "SGi",
                                "IBMPC",      "IBMRS",
-                               "HOST",       "MAC",
+                               "HOST",       "PPC",
                                " ",          "HP",
                                "NeXT",       "ALPHAOSF1",
                                "ALPHAVMSd",  "ALPHAVMSg",
@@ -855,7 +890,7 @@ public class CDFUtils implements CDFConstants {
      *             <LI>IBMPC_DECODING
      *             <LI>IBMRS_DECODING
      *             <LI>HOST_DECODING
-     *             <LI>MAC_DECODING
+     *             <LI>PPC_DECODING
      *             <LI>HP_DECODING
      *             <LI>NeXT_DECODING
      *             <LI>ALPHAOSF1_DECODING
@@ -1064,6 +1099,32 @@ public class CDFUtils implements CDFConstants {
         return (sType);
     }
 
+    /**
+     *  Gets the long value of the given CDF's checksum in string. <P>
+     *
+     *  @param checksum the checksum string of which to be translated.
+     *  @return long value of checksum type. The returned
+     *          value is either NONE_CHECKSUM, MD5_CHECKSUM,
+     *          or OTHER_CHECKSUM.
+     */
+    public static long getLongChecksum (String checksum) {
+        long cType;
+        if (checksum.equalsIgnoreCase("None"))
+            cType = NONE_CHECKSUM;
+
+        else if (checksum.equalsIgnoreCase("md5"))
+            cType = MD5_CHECKSUM;
+
+        else if (checksum.equalsIgnoreCase("other"))
+            cType = OTHER_CHECKSUM;
+
+        else
+            cType = NO_CHECKSUM;
+
+        return (cType);
+
+    }
+
     /**
      *  Gets the string value of the given CDF's checksum. <P>
      *
