@@ -1,4 +1,4 @@
-// $Id: Epoch.java,v 1.1.1.1 2009/01/20 16:27:22 liu Exp $
+// $Id: Epoch.java,v 1.3 2010/12/21 16:30:50 liu Exp $
 package gsfc.nssdc.cdf.util;
 
 import gsfc.nssdc.cdf.CDFException;
@@ -24,6 +24,7 @@ import java.text.*;
  * System.out.println(Epoch.encode1(ep));
  * System.out.println(Epoch.encode2(ep));
  * System.out.println(Epoch.encode3(ep));
+ * System.out.println(Epoch.encode4(ep));
  * // Print out the date using format
  * String format = "<month> <dom.02>, <year> at <hour>:<min>";
  * System.out.println(Epoch.encodex(ep,format));
@@ -258,6 +259,60 @@ public class Epoch implements gsfc.nssdc.cdf.CDFConstants {
 	}
     }
 
+    /**
+     * 
+     * This function parses an input date/time string and returns an EPOCH
+     * value.  The format must be an ISO8601 and is exactly as shown below.
+     *
+     * <PRE>
+     * Format:    yyyy-mm-ddThh:mm:ss.ccc
+     * Examples:  1990-04-01T03:05:02.000
+     *            1993-10-10T23:45:49.999
+     * </PRE>
+     *
+     * The expected format is the same as that produced by encodeEPOCH3.
+     *
+     * @param inString the epoch in string representation
+     * @return the value of the epoch represented by inString
+     *
+     * @exception CDFException if a bad epoch value is passed in inString
+     */
+    public static double parse4 (String inString)
+	throws CDFException
+    {
+	long year = 0, month = 0, day = 0, hour = 0, 
+	    minute = 0, second = 0, msec = 0;
+
+	String secondStr;
+
+	try {
+	    // Breakup the date and time fields
+	    StringTokenizer st = new StringTokenizer(inString, "T");
+	    String date = st.nextToken();
+	    String tt = st.nextToken();
+	    String time = tt.substring(0,tt.length() - 1);
+
+	    // Breakup the date portion
+	    st = new StringTokenizer(date, "-");
+	    year = Long.parseLong(st.nextToken());
+	    month = Long.parseLong(st.nextToken());
+	    day = Long.parseLong(st.nextToken());
+
+	    // Get the time portion
+	    st = new StringTokenizer(time, ":");
+	    hour   = Long.parseLong(st.nextToken());
+	    minute = Long.parseLong(st.nextToken());
+	    secondStr = st.nextToken();
+	    st = new StringTokenizer(secondStr, ".");
+	    second = Long.parseLong(st.nextToken());
+	    msec   = Long.parseLong(st.nextToken());
+
+	    return compute(year, month, day, hour, minute, second, msec);
+	} catch (java.lang.Exception e) {
+	    throw new CDFException(ILLEGAL_EPOCH_FIELD);
+	}
+    }
+
     /**
      * 
      * Converts an EPOCH value into a readable date/time string.
@@ -361,6 +416,33 @@ public class Epoch implements gsfc.nssdc.cdf.CDFConstants {
 		     "<year>-<mm.02>-<dom.02>T<hour>:<min>:<sec>.<fos>Z");
     }
 
+    /**
+     * 
+     * Converts an EPOCH value into a readable date/time, ISO8601 string.
+     *
+     * <PRE>
+     * Format:    yyyy-mm-ddThh:mm:ss.ccc
+     * Examples:  1990-04-01T03:05:02.000
+     *            1993-10-10T23:45:49.999
+     * </PRE>
+     *
+     * This format is the same as that expected by parse3.
+     *
+     * @param epoch the epoch value
+     *
+     * @return A string representation of the epoch
+     */
+    public static String encode4 (double epoch)
+    {
+        if (epoch == -1.0E31) {
+          return "9999-12-31T23:59:59.999";
+        }
+        
+	return 
+	    encodex (epoch, 
+		     "<year>-<mm.02>-<dom.02>T<hour>:<min>:<sec>.<fos>");
+    }
+
     /**
      * 
      * Converts an EPOCH value into a readable date/time string using the
@@ -664,56 +746,49 @@ public class Epoch implements gsfc.nssdc.cdf.CDFConstants {
     {
 	long daysSince0AD, msecInDay;
 
-	if (year == 9999 && month == 12 && day == 31 && hour == 23 &&
-            minute == 59 && second == 59 && msec == 999) 
+	if (year == 9999L && month == 12L && day == 31L && hour == 23L &&
+            minute == 59L && second == 59L && msec == 999L) 
           return -1.0E31;
 	/*
 	 * Calculate the days since 0 A.D (1-Jan-0000).  If a value of zero 
 	 * is passed in for `month', assume that `day' is the day-of-year
 	 * (DOY) with January 1st being day 1.
 	 */
-	if (year < 0 || year > 9999) 
-	    throw new CDFException(ILLEGAL_EPOCH_FIELD);
-	if (month < 0 || month > 12)
-	    throw new CDFException(ILLEGAL_EPOCH_FIELD);
-
+        if (year < 0L) throw new CDFException(ILLEGAL_EPOCH_VALUE);
+        if ((year > 9999L) || (month < 0L || month > 12L) ||
+            (hour < 0L || hour > 23L) || (minute < 0L || minute > 59L) ||
+            (second < 0L || second > 59L) || (msec < 0L || msec > 999L))
+          return computeEpoch(year,month,day,hour,minute,second,msec);
+        if (month == 0L) {
+          if (day < 1L || day > 366L)
+            return computeEpoch(year,month,day,hour,minute,second,msec);
+        } else {
+          if (day < 1L || day > 31L)
+            return computeEpoch(year,month,day,hour,minute,second,msec);
+        }
+        if (hour == 0L && minute == 0L && second == 0L) {
+          if (msec < 0L || msec > 86399999L)
+            return computeEpoch(year,month,day,hour,minute,second,msec);
+        }
 	if (month == 0) {
-	    if (day < 1 || day > 366) 
-		throw new CDFException(ILLEGAL_EPOCH_FIELD);
-	    daysSince0AD = (JulianDay(year,1L,1L) + (day-1)) - 1721060L;
+	    daysSince0AD = JulianDay(year,1L,1L) + (day-1) - 1721060L;
 	} else {
-	    if (day < 1 || day > 31) 
-		throw new CDFException(ILLEGAL_EPOCH_FIELD);
 	    daysSince0AD = JulianDay(year,month,day) - 1721060L;
 	}
-
 	/*
 	 * Calculate the millisecond in the day (with the first millisecond
 	 * being 0). If values of zero are passed in for `hour', `minute',
 	 * and `second', assume that `msec' is the millisecond in the day.
 	 */
 	if (hour == 0 && minute == 0 && second == 0) {
-	    if (msec < 0 || msec > 86399999L) 
-		throw new CDFException(ILLEGAL_EPOCH_FIELD);
 	    msecInDay = msec;
 	} else {
-	    if (hour < 0 || hour > 23) 
-		throw new CDFException(ILLEGAL_EPOCH_FIELD);
-	    if (minute < 0 || minute > 59) 
-		throw new CDFException(ILLEGAL_EPOCH_FIELD);
-	    if (second < 0 || second > 59) 
-		throw new CDFException(ILLEGAL_EPOCH_FIELD);
-	    if (msec < 0 || msec > 999) 
-		throw new CDFException(ILLEGAL_EPOCH_FIELD);
-	    msecInDay = 
-		(3600000L * hour) + 
-		(60000L * minute) + 
-		(1000 * second) + 
-		msec;
+	    msecInDay = (3600000L * hour) + (60000L * minute) + 
+             		(1000L * second) + msec;
 	}
 	
 	// Return the milliseconds since 0 A.D.
-	return ((86400000L * ((double) daysSince0AD)) + ((double) msecInDay));
+	return (86400000.0 * daysSince0AD + (double) msecInDay);
     }
 
     /**
@@ -798,4 +873,35 @@ public class Epoch implements gsfc.nssdc.cdf.CDFConstants {
 		d +
 		1721029);
     }
+
+    /**
+     * computeEpoch.
+     * This is the millseconds since 0 AD/1 BC.
+     */
+    private static double computeEpoch (long y, long m, long d, long h, long mn,
+                                        long s, long ms) throws CDFException
+    {
+        long daysSince0AD;
+        double msecInDay;
+        if (m == 0L) {
+          daysSince0AD = JulianDay(y,1L,1L) + (d-1L) - 1721060L;
+        }
+        else {
+          if (m < 0L) {
+            --y;
+            m = 13 + m;
+          }
+          daysSince0AD = JulianDay(y,m,d) - 1721060L;
+        }
+        if (daysSince0AD < 1L) 
+         throw new CDFException(ILLEGAL_EPOCH_VALUE);
+        msecInDay = 3600000.0 * h + 60000.0 * mn + 1000.0 * s +
+                    (double) ms;
+        double msecFromEpoch =  86400000.0 * daysSince0AD + msecInDay;
+        if (msecFromEpoch < 0.0)
+          return ILLEGAL_EPOCH_VALUE;
+        else
+          return msecFromEpoch;
+    }
+
 }
