@@ -1,4 +1,4 @@
-// $Id: Epoch16.java,v 1.1.1.1 2009/01/20 16:27:22 liu Exp $
+// $Id: Epoch16.java,v 1.3 2010/12/21 16:30:50 liu Exp $
 package gsfc.nssdc.cdf.util;
 
 import gsfc.nssdc.cdf.CDFException;
@@ -26,6 +26,7 @@ import java.text.*;
  * System.out.println(Epoch16.encode1(epoch16));
  * System.out.println(Epoch16.encode2(epoch16));
  * System.out.println(Epoch16.encode3(epoch16));
+ * System.out.println(Epoch16.encode4(epoch16));
  * // Print out the date using format
  * String format = "<month> <dom.02>, <year> at <hour>:<min>";
  * System.out.println(Epoch16.encodex(epoch16,format));
@@ -239,7 +240,7 @@ public class Epoch16 implements gsfc.nssdc.cdf.CDFConstants {
     
     /**
      * 
-     * This function parses an  input date/time string and returns an EPOCH16
+     * This function parses an input date/time string and returns an EPOCH16
      * value.  The format must be exactly as shown below.
      *
      * <PRE>
@@ -301,6 +302,69 @@ public class Epoch16 implements gsfc.nssdc.cdf.CDFConstants {
 	}
     }
 
+    /**
+     * 
+     * This function parses an input date/time, ISO8601 string and returns
+     * an EPOCH16 value.  The format must be exactly as shown below.
+     *
+     * <PRE>
+     * Format:            yyyy-mm-ddThh:mm:ss.cccmmmnnnppp
+     * Examples:          1990-04-01T03:05:02.000000000000
+     *                    1993-10-10T23:45:49.999999999999
+     * </PRE>
+     *
+     * The expected format is the same as that produced by encode3.
+     *
+     * @param inString the epoch in string representation
+     * @return the value of the epoch represented by inString
+     *
+     * @exception CDFException if a bad epoch value is passed in inString
+     */
+    public static Object parse4 (String inString)
+	throws CDFException
+    {
+	long year = 0, month = 0, day = 0, hour = 0, 
+	    minute = 0, second = 0, msec = 0, usec = 0, nsec = 0, psec = 0;
+
+	String secondStr;
+	double[] epoch16 = new double[2];
+	double mmm;
+
+	try {
+	    // Breakup the date and time fields
+    	    StringTokenizer st = new StringTokenizer(inString, "T");
+	    String date = st.nextToken();
+	    String time = st.nextToken();
+	    String fracSec;
+
+	    // Breakup the date portion
+	    st = new StringTokenizer(date, "-");
+	    year = Long.parseLong(st.nextToken());
+	    month = Long.parseLong(st.nextToken());
+	    day = Long.parseLong(st.nextToken());
+
+	    // Get the time portion
+	    st = new StringTokenizer(time, ":");
+	    hour   = Long.parseLong(st.nextToken());
+	    minute = Long.parseLong(st.nextToken());
+	    secondStr = st.nextToken();
+	    st = new StringTokenizer(secondStr, ".");
+	    second = Long.parseLong(st.nextToken());
+            String subSecs = st.nextToken();
+	    msec = Long.parseLong(subSecs.substring(0,3));
+	    usec = Long.parseLong(subSecs.substring(3,6));
+	    nsec = Long.parseLong(subSecs.substring(6,9));
+	    psec = Long.parseLong(subSecs.substring(9,12));
+	    mmm =  compute(year, month, day, hour, minute, second, 
+			   msec, usec,  nsec, psec, epoch16);
+	    if (mmm == ILLEGAL_EPOCH_VALUE)
+	      throw new CDFException(ILLEGAL_EPOCH_FIELD);
+	    return epoch16;
+	} catch (java.lang.Exception e) {
+	    throw new CDFException(ILLEGAL_EPOCH_FIELD);
+	}
+    }
+
     /**
      * 
      * Converts an EPOCH16 value into a readable date/time string.
@@ -423,6 +487,36 @@ public class Epoch16 implements gsfc.nssdc.cdf.CDFConstants {
 		     "<year>-<mm.02>-<dom.02>T<hour>:<min>:<sec>.<fos>Z");
     }
 
+    /**
+     * 
+     * Converts an EPOCH16 value into a readable date/time, ISO8601  string.
+     *
+     * <PRE>
+     * Format:            yyyy-mm-ddThh:mm:ss.cccmmmnnnppp
+     * Examples:          1990-04-01T03:05:02.000000000000
+     *                    1993-10-10T23:45:49.999999999999
+     * </PRE>
+     *
+     * This format is the same as that expected by parse4.
+     *
+     * @param epoch the epoch value
+     *
+     * @return A string representation of the epoch
+     */
+    public static String encode4 (Object epoch)
+    {
+        double[] epoch16 = new double[2];
+        epoch16[0] = ((double[]) epoch)[0];
+        epoch16[1] = ((double[]) epoch)[1];
+        if ((epoch16[0] == -1.0E31) && (epoch16[1] == -1.0E31)) {
+          return "9999-12-31T23:59:59.999999999999";
+        }
+
+	return 
+	    encodex (epoch16, 
+		     "<year>-<mm.02>-<dom.02>T<hour>:<min>:<sec>.<iso8601>");
+    }
+
     /**
      * 
      * Converts an EPOCH16 value into a readable date/time string using the
@@ -566,6 +660,18 @@ public class Epoch16 implements gsfc.nssdc.cdf.CDFConstants {
 			appendIntegerPart(encoded, components[9], 3, true, 
 					  mod.toString());
 		    }
+
+		    // Fraction of second, <iso8601>.
+		    else if (sPart.indexOf("iso8601") == 0) {
+			double fos = ((double) components[6]) / 1000.0;
+			appendFractionPart(encoded, fos, 3, mod.toString());
+			appendIntegerPart(encoded, components[7], 3, true, 
+					  mod.toString());
+			appendIntegerPart(encoded, components[8], 3, true, 
+					  mod.toString());
+			appendIntegerPart(encoded, components[9], 3, true, 
+					  mod.toString());
+		    }
 		    
 		    // Fraction of day, <fod>.
 		    else if (sPart.indexOf("fod") == 0) {
@@ -752,9 +858,9 @@ public class Epoch16 implements gsfc.nssdc.cdf.CDFConstants {
 	long daysSince0AD, secInDay;
 	double[] epoch16 = new double[2];
 
-        if (year == 9999 && month == 12 && day == 31 && hour == 23 &&
-            minute == 59 && second == 59 && msec == 999 && usec == 999 &&
-            nsec == 999 && psec == 999) {
+        if (year == 9999L && month == 12L && day == 31L && hour == 23L &&
+            minute == 59L && second == 59L && msec == 999L && usec == 999L &&
+            nsec == 999L && psec == 999L) {
           ((double[]) epoch)[0] = -1.0E31;
           ((double[]) epoch)[1] = -1.0E31;
           return 0.0;
@@ -765,42 +871,36 @@ public class Epoch16 implements gsfc.nssdc.cdf.CDFConstants {
 	 * is passed in for `month', assume that `day' is the day-of-year
 	 * (DOY) with January 1st being day 1.
 	 */
-	if (year < 0 || year > 9999) 
+	if (year < 0L) 
 	    throw new CDFException(ILLEGAL_EPOCH_FIELD);
-	if (month < 0 || month > 12)
-	    throw new CDFException(ILLEGAL_EPOCH_FIELD);
-
-	if (month == 0) {
-	    if (day < 1 || day > 366) 
-		throw new CDFException(ILLEGAL_EPOCH_FIELD);
+        if ((year > 9999L) || (month < 0L || month > 12L) ||
+            (hour < 0L || hour > 23L) || (minute < 0L || minute > 59L) ||
+            (second < 0L || second > 59L) || (msec < 0L || msec > 999L) ||
+            (usec < 0L || usec > 999L) || (nsec < 0L || nsec > 999L) ||
+            (psec < 0L || psec > 999L))
+          return computeEpoch16(year, month, day, hour, minute, second, msec, 
+                                usec, nsec, psec, epoch);
+	if (month == 0L) {
+          if (day < 1L || day > 366L)
+            return computeEpoch16(year,month,day,hour,minute,second,msec,usec,
+                                  nsec, psec, epoch);
 	    daysSince0AD = (JulianDay(year,1L,1L) + (day-1)) - 1721060L;
 	} else {
-	    if (day < 1 || day > 31) 
-		throw new CDFException(ILLEGAL_EPOCH_FIELD);
+          if (day < 1L || day > 31L)
 	    daysSince0AD = JulianDay(year,month,day) - 1721060L;
 	}
-
-	if (hour < 0 || hour > 23) 
-		throw new CDFException(ILLEGAL_EPOCH_FIELD);
-	if (minute < 0 || minute > 59) 
-		throw new CDFException(ILLEGAL_EPOCH_FIELD);
-	if (second < 0 || second > 59) 
-		throw new CDFException(ILLEGAL_EPOCH_FIELD);
-	if (msec < 0 || msec > 999) 
-		throw new CDFException(ILLEGAL_EPOCH_FIELD);
-        if (usec < 0 || usec > 999)
-                throw new CDFException(ILLEGAL_EPOCH_FIELD);
-        if (nsec < 0 || nsec > 999)
-                throw new CDFException(ILLEGAL_EPOCH_FIELD);
-        if (psec < 0 || psec > 999)
-                throw new CDFException(ILLEGAL_EPOCH_FIELD);
-
+        if (month == 0L) {
+          daysSince0AD = JulianDay(year,1L,1L) + (day-1) - 1721060L;
+        }
+        else {
+          daysSince0AD = JulianDay(year,month,day) - 1721060L;
+        }
 	secInDay = (3600L * hour) + (60L * minute) + second; 
 	
 	// Return the picoseconds, in two double words, since 0 A.D.
-	epoch16[0] = 86400L * (double) daysSince0AD + (double) secInDay;
-	epoch16[1] = psec + nsec * Math.pow(10.0, 3.0) +
-		     usec * Math.pow(10.0, 6.0) + msec * Math.pow(10.0, 9.0);
+	epoch16[0] = 86400.0 * daysSince0AD + (double) secInDay;
+	epoch16[1] = (double) psec + Math.pow(10.0, 3.0) * nsec +
+		     Math.pow(10.0, 6.0) * usec + Math.pow(10.0, 9.0) * msec;
 	((double[]) epoch)[0] = epoch16[0];
 	((double[]) epoch)[1] = epoch16[1];
 	return 0.0;
@@ -946,4 +1046,63 @@ public class Epoch16 implements gsfc.nssdc.cdf.CDFConstants {
 	fracString.append(encoded); 
 	return fracString.toString();
     }
+
+    /**
+     * computeEpoch16.
+     * This is the seconds and picoseconds since 0 AD/1 BC.
+     */
+    private static double computeEpoch16 (long y, long m, long d, long h,
+                                          long mn, long s, long ms, long msu,
+                                          long msn, long msp, Object epoch)
+                                          throws CDFException
+    {
+        long daysSince0AD;
+        if (m == 0L) {
+          daysSince0AD = JulianDay(y,1L,1L) + (d-1L) - 1721060L;
+        }
+        else {
+          if (m < 0L) {
+            --y;
+            m = 13 + m;
+          }
+          daysSince0AD = JulianDay(y,m,d) - 1721060L;
+        }
+        if (daysSince0AD < 0L)
+          throw new CDFException(ILLEGAL_EPOCH_VALUE);
+        ((double[]) epoch)[0] = 86400.0 * daysSince0AD + 3600.0 * h + 60.0 *
+                                mn + (double) s;
+        ((double[]) epoch)[1] = (double) msp + Math.pow(10.0, 3.0) * msn +
+                   Math.pow(10.0, 6.0) * msu + Math.pow(10.0, 9.0) * ms;
+        if (((double[]) epoch)[1] < 0.0 || 
+            ((double[]) epoch)[1] >= Math.pow(10.0, 12.0)) {
+          int sec;
+          double tmp;
+          if (((double[]) epoch)[1] < 0.0) {
+            sec = (int) (((double[]) epoch)[1] / Math.pow(10.0, 12.0));
+            tmp = ((double[]) epoch)[1] - sec * Math.pow(10.0, 12.0);
+            if (tmp != 0.0 && tmp != -0.0) {
+              ((double[]) epoch)[0] = ((double[]) epoch)[0] + sec - 1;
+              ((double[]) epoch)[1] = Math.pow(10.0, 12.0) + tmp;
+            } else {
+              ((double[]) epoch)[0] = ((double[]) epoch)[0] + sec;
+              ((double[]) epoch)[1] = 0.0;
+            }
+          } else {
+            sec = (int) (((double[]) epoch)[1] / Math.pow(10.0, 12.0));
+            tmp = ((double[]) epoch)[1] - sec * Math.pow(10.0, 12.0);
+            if (tmp != 0.0 && tmp != -0.0) {
+              ((double[]) epoch)[1] = tmp;
+              ((double[]) epoch)[0] = ((double[]) epoch)[0] + sec;
+            } else {
+              ((double[]) epoch)[1] = 0.0;
+              ((double[]) epoch)[0] = ((double[]) epoch)[0] + sec;
+            }
+          }
+        }
+        if (((double[]) epoch)[0] < 0.0)
+          return ILLEGAL_EPOCH_VALUE;
+        else
+          return 0.0;
+    }
+
 }
